/*
 * file tarot/cnn.h Convolutional Neural Network.
 *
 * Copyright (C) 2019 Vivien Kraus <vivien@planete-kraus.eu>
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

#ifndef H_TAROT_CNN_INCLUDED
#define H_TAROT_CNN_INCLUDED

#include <stddef.h>

#ifdef __cplusplus
extern "C"
{
#endif

  struct TarotGame;
  struct TarotPredictor;

  /**
   * tarot_cnn_predict:
   * @score: (array length=max_score):
   */
  size_t tarot_cnn_predict (const TarotGame *game, size_t max_score, double *score);

  /**
   * tarot_cnn_predict_alloc:
   * @score: (out) (array length=n_score):
   * @n_score: (out):
   */
  void tarot_cnn_predict_alloc (const TarotGame *game, double **score, size_t *n_score);

  /**
   * tarot_cnn_predictor_construct:
   * @mem: (array length=max_mem):
   * @alignment: (out):
   */
  size_t tarot_cnn_predictor_construct (size_t max_mem, char *mem, size_t *alignment);

  /**
   * tarot_cnn_predictor_alloc:
   */
  struct TarotPredictor *tarot_cnn_predictor_alloc (void);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* not H_TAROT_CNN_INCLUDED */
